Module apply

Module apply 

Write a SplitPlan to disk with a snapshot that supports full rollback.

Structs

Applied
A split that has been written to disk and can be rolled back.

Functions

format_files
Best-effort rustfmt on the given files; ignores all failures.
write_plan
Write the plan to disk. Performs a conflict check first and never overwrites an existing module file.