Module verify

Module verify 

Compiler-based verification: locate the crate manifest and run cargo check.

Structs

CheckResult
Result of a cargo check run.

Functions

cargo_check
Run cargo check in manifest_dir. all_targets also checks tests/examples/benches.
error_excerpt
Keep only the most relevant tail of a cargo error log for reporting.
find_manifest_dir
Walk upward from start to find the directory containing Cargo.toml.