Write a SplitPlan to disk with a snapshot that supports full rollback.
Structs
- Applied
- A split that has been written to disk and can be rolled back.
Functions
- format_
files - Best-effort
rustfmton the given files; ignores all failures. - write_
plan - Write the plan to disk. Performs a conflict check first and never overwrites an existing module file.